@@ -11,11 +11,12 @@
 
 
 import functools
-import json
 import logging
+from concurrent.futures import Future
 from datetime import datetime
+from typing import Callable, Optional, Protocol, TypedDict
 
-from common.utils import check_command_output, time_is_up
+from common.utils import check_command_output, time_is_up, validate_absolute_path
 
 logger = logging.getLogger(__name__)
 
@@ -24,6 +25,36 @@ logger = logging.getLogger(__name__)
 TIMESTAMP_FORMAT = "%Y-%m-%d %H:%M:%S.%f%z"
 DEFAULT_COMMAND_TIMEOUT = 30
 
+ComputeInstanceDescriptor = TypedDict(
+    "ComputeInstanceDescriptor",
+    {
+        "Name": str,
+        "InstanceId": str,
+    },
+)
+
+
+class TaskController(Protocol):
+    class TaskShutdownError(RuntimeError):
+        """Exception raised if shutdown has been requested."""
+
+        pass
+
+    def queue_task(self, task: Callable[[], None]) -> Optional[Future]:
+        """Queue a task and returns a Future for the task or None if the task could not be queued."""
+
+    def is_shutdown(self) -> bool:
+        """Is shutdown has been requested."""
+
+    def raise_if_shutdown(self) -> None:
+        """Raise an error if a shutdown has been requested."""
+
+    def wait_unless_shutdown(self, seconds_to_wait: float) -> None:
+        """Wait for seconds_to_wait or will raise an error if a shutdown has been requested."""
+
+    def shutdown(self, wait: bool, cancel_futures: bool) -> None:
+        """Request that all tasks be shutdown."""
+
 
 def log_exception(
     logger,
@@ -59,34 +90,20 @@ def print_with_count(resource_list):
     return f"(x{len(resource_list)}) {str(resource_list)}"
 
 
-def read_json(file_path, default=None):
-    """Read json file into a dict."""
-    try:
-        with open(file_path) as mapping_file:
-            return json.load(mapping_file)
-    except Exception as e:
-        if default is None:
-            logger.error(
-                "Unable to read file from '%s'. Failed with exception: %s",
-                file_path,
-                e,
-            )
-            raise
-        else:
-            logger.info("Unable to read file '%s' due to an exception: %s. Using default: %s", file_path, e, default)
-            return default
-
-
 def get_clustermgtd_heartbeat(clustermgtd_heartbeat_file_path):
     """Get clustermgtd's last heartbeat."""
     # Use subprocess based method to read shared file to prevent hanging when NFS is down
     # Do not copy to local. Different users need to access the file, but file should be writable by root only
     # Only use last line of output to avoid taking unexpected output in stdout
+
+    # Validation to sanitize the input argument and make it safe to use the function affected by B604
+    validate_absolute_path(clustermgtd_heartbeat_file_path)
+
     heartbeat = (
         check_command_output(
             f"cat {clustermgtd_heartbeat_file_path}",
             timeout=DEFAULT_COMMAND_TIMEOUT,
-            shell=True,  # nosec
+            shell=True,  # nosec B604
         )
         .splitlines()[-1]
         .strip()
